Struct massbit_sol::generator::Generator [−][src]
pub struct Generator<'a> {
pub structure_path: &'a str,
pub config_path: &'a str,
pub output_dir: &'a str,
pub schema: Option<Schema>,
pub config: Option<Value>,
pub definitions: BTreeMap<String, Schema>,
}Fields
structure_path: &'a strconfig_path: &'a stroutput_dir: &'a strThe output dir
schema: Option<Schema>config: Option<Value>definitions: BTreeMap<String, Schema>Implementations
pub fn expand_handler_patterns(
&self,
enum_name: &String,
variants: &VariantArray
) -> Vec<String>ⓘ
pub fn expand_handler_functions(&self, variants: &VariantArray) -> Vec<String>ⓘ
Return true if value of a property is optional A property can be none when unpacking if Property is not a vector, data_type is NonZero* or some user defined struct or enum